/* Un ou plusieurs objets doivent être trouvés pour pouvoir activer l'objet à activer
   Lorsqu'un objet est trouvé alors :
   		il devient invisible et non détectable, 
   		s'il possède un son alors le son joue 
   		s'il possède des enfants alors ils s'activent, exemple: des particules

   Lorsqu'on touche l'objet à activer, si tous les objets sont trouvés alors:
   	 s'il possède un son alors le son joue 
   	 s'il possède une animation alors elle joue
   
   S'il y a une caméra alors elle s'active lorsque tous les objets sont trouvés.
*/

var TrouverObjets: GameObject[];
var ActiverObjet: GameObject;
var ActiverCamera: GameObject;
var DureeCamera: int = 5;

private
var NombreObjetTrouve = 0;


function OnControllerColliderHit(hit: ControllerColliderHit) {
	if (TrouverObjets.Length > 0) {
		// ramasser les objets
		for (var objet in TrouverObjets)
		if (objet != null) {
			if (hit.collider.name == objet.name) {
				objet.renderer.enabled = false;
				objet.collider.enabled = false;


				//rend les enfants invisibles, 
				var renderDesEnfants = objet.GetComponentsInChildren(Renderer);
				for (var enfant: Renderer in renderDesEnfants) {
					enfant.renderer.enabled = false;
				}

				objet.SetActiveRecursively(true);

				if (objet.GetComponent("AudioSource")) objet.audio.Play();
				NombreObjetTrouve++;

				//on peut activer la camera si on a trouvé le dernier objet
				if (ActiverCamera != null && NombreObjetTrouve == TrouverObjets.Length) {
					var cameraPersonnage = Camera.main.gameObject;
					Camera.main.gameObject.active = false;
					ActiverCamera.active = true;
					yield WaitForSeconds(DureeCamera);
					cameraPersonnage.active = true;
					ActiverCamera.active = false;
				}
			}
		} else print("Il y a des objets vides à trouver dans les paramètres de l'inspecteur!!!!");
		//si tous les objets sont trouvés
		// si maintenant on touche l'objet à activer alors il s'active 
		if (ActiverObjet != null && NombreObjetTrouve == TrouverObjets.Length) {
			//vérifier si on touche les enfants, au cas où l'objet à activer est un objet parent vide
			var ColliderDesEnfants = ActiverObjet.GetComponentsInChildren(Collider);
			for (var enfant : Collider in ColliderDesEnfants){
				if (hit.collider.name == ActiverObjet.name) {
					if (ActiverObjet.GetComponent("Animation")) ActiverObjet.animation.Play();
					if (ActiverObjet.GetComponent("AudioSource")) ActiverObjet.audio.Play();
					NombreObjetTrouve = -1; // pour empêcher d'activer plusieurs fois cette objet
				}
			}
		} else print("Aucun objet à activer");

	} else print("Il faut identifier les objets à trouver dans l'inspecteur");

}

function Update() {

	// arrêter le son de l'objet lorsque son animation se termine
	if (ActiverObjet != null)
	  if (!ActiverObjet.animation.isPlaying && ActiverObjet.GetComponent("AudioSource") && NombreObjetTrouve == -1)
		ActiverObjet.audio.Stop();


}