/*
Lors d’une collision entre le personnage et un objet, ce script active un ou plusieurs autres objets.
 
	Lorsque l’objet est touché :
	•s’il possède une animation alors, elle s’exécute;
	•s'il possède un son alors, le son joue;
	•s'il possède des enfants alors, ces derniers s'activent (ce peut être des particules).
	•pour chaque objet à activer :
	◦s'il possède un son alors, le son joue;
	
	◦s'il possède une animation alors, elle s’exécute.
	
	•chaque objet à désactiver devient invisible et s’efface.
	
	•s'il y a une caméra alors, elle s'active temporairement pendant le temps indiqué dans les paramètres.

*/

var ObjetTouche: GameObject;
var ActiverObjets: GameObject[];
var MasquerObjets: GameObject[];
var ActiverCamera: GameObject;

var DureeCamera: int = 5;


private
var ObjetToucheActive = false;

function OnControllerColliderHit(hit: ControllerColliderHit) {
	if (ObjetTouche != null) {
		if (hit.collider.name == ObjetTouche.name && !ObjetToucheActive) {
			ObjetToucheActive = true;

			//hit.collider.renderer.material.color = Color.green;
			ObjetTouche.SetActiveRecursively(true);
			if (ObjetTouche.GetComponent("Animation")) ObjetTouche.animation.Play();
			if (ObjetTouche.GetComponent("AudioSource")) ObjetTouche.audio.Play();

			for (var objet in ActiverObjets)
				if (objet != null) {
					objet.SetActiveRecursively(true);
					if (objet.GetComponent("Animation")) objet.animation.Play();
					if (objet.GetComponent("AudioSource")) objet.audio.Play();
				}

			for (var objet in MasquerObjets)
				if (objet != null) {
					objet.SetActiveRecursively(false);
				}

			if (ActiverCamera != null) {
				var cameraPersonnage = Camera.main.gameObject;
				//Debug.Log(cameraPersonnage);
				Camera.main.gameObject.active = false;
				ActiverCamera.active = true;
				yield WaitForSeconds(DureeCamera);
				cameraPersonnage.active = true;
				ActiverCamera.active = false;
			}
		}
	}
}

function Update() {
	for (var objet in ActiverObjets)
	  if (objet != null &&  objet.GetComponent("Animation") && !objet.animation.isPlaying && objet.GetComponent("AudioSource"))
		 objet.audio.Stop();
}